
Note "DayOfWeek" is 0 for Monday, 1 for Tuesday etc.

.. code-block:: python

    {
        "DailySchedules": [
            {
                "DayOfWeek": 0,
                "Switchpoints": [
                    {
                        "TargetTemperature": 21.0,
                        "TimeOfDay": "06:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "08:00:00"
                    },
                    {
                        "TargetTemperature": 19.0,
                        "TimeOfDay": "16:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "20:00:00"
                    }
                ]
            },
            {
                "DayOfWeek": 1,
                "Switchpoints": [
                    {
                        "TargetTemperature": 21.0,
                        "TimeOfDay": "06:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "08:00:00"
                    },
                    {
                        "TargetTemperature": 19.0,
                        "TimeOfDay": "16:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "20:00:00"
                    }
                ]
            },
            {
                "DayOfWeek": 2,
                "Switchpoints": [
                    {
                        "TargetTemperature": 21.0,
                        "TimeOfDay": "06:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "08:00:00"
                    },
                    {
                        "TargetTemperature": 19.0,
                        "TimeOfDay": "16:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "20:00:00"
                    }
                ]
            },
            {
                "DayOfWeek": 3,
                "Switchpoints": [
                    {
                        "TargetTemperature": 21.0,
                        "TimeOfDay": "06:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "08:00:00"
                    },
                    {
                        "TargetTemperature": 19.0,
                        "TimeOfDay": "16:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "20:00:00"
                    },
                    {
                        "TargetTemperature": 17.5,
                        "TimeOfDay": "23:00:00"
                    }
                ]
            },
            {
                "DayOfWeek": 4,
                "Switchpoints": [
                    {
                        "TargetTemperature": 21.0,
                        "TimeOfDay": "06:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "08:00:00"
                    },
                    {
                        "TargetTemperature": 19.0,
                        "TimeOfDay": "16:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "20:00:00"
                    }
                ]
            },
            {
                "DayOfWeek": 5,
                "Switchpoints": [
                    {
                        "TargetTemperature": 21.0,
                        "TimeOfDay": "06:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "08:00:00"
                    },
                    {
                        "TargetTemperature": 19.0,
                        "TimeOfDay": "16:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "20:00:00"
                    }
                ]
            },
            {
                "DayOfWeek": 6,
                "Switchpoints": [
                    {
                        "TargetTemperature": 21.0,
                        "TimeOfDay": "06:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "08:00:00"
                    },
                    {
                        "TargetTemperature": 19.0,
                        "TimeOfDay": "16:30:00"
                    },
                    {
                        "TargetTemperature": 15.0,
                        "TimeOfDay": "20:00:00"
                    }
                ]
            }
        ]
    }
